pub struct StatefulProcessor<C: ServiceContext> { /* private fields */ }Expand description
Stateful message processor that wraps a context and handler
Implementations
Sourceimpl<C: ServiceContext> StatefulProcessor<C>
impl<C: ServiceContext> StatefulProcessor<C>
Sourcepub fn new<H>(context: C, handler: H) -> Selfwhere
H: StatefulHandler<C> + 'static,
pub fn new<H>(context: C, handler: H) -> Selfwhere
H: StatefulHandler<C> + 'static,
Create a new stateful processor with context and handler
Sourcepub fn builder(context: C) -> StatefulProcessorBuilder<C>
pub fn builder(context: C) -> StatefulProcessorBuilder<C>
Create a builder for configuring the processor